==> sfzn-api-2.0.1-sources.jar: com/picc/gz/sfzn/api/vo/recommend/SalerInfo.java <==
package com.picc.gz.sfzn.api.vo.recommend;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @author Liang Wenxu
 * @since 2018/11/20
 */
public class SalerInfo implements Serializable {
    /**
     * 归属机构码
     */
    private String comCode;
    /**
     * 出单机构码
     */
    private String makeCode;
    /**
     * 经办人码
     */
    private String handlerCode;
    /**
     * 归属业务员码
     */
    private String handler1Code;
    /**
     * 操作员码
     */
    private String operatorCode;

    /**
     * 销售人员码
     */
    private String sellerno;
    /**
     * 销售人员名字
     */
    private String sellername;

    /**
     * 渠道码
     */
    private String agentcode;

    /**
     * 跟单费率，百分比整数，例如0.25传25
     */
    private Integer sellfeerate;

    /**
     * 每月佣金上限（保留2位小数）
     */
    private BigDecimal commissionLimit;


    public String getComCode() {
        return comCode;
    }

    public void setComCode(String comCode) {
        this.comCode = comCode;
    }

    public String getMakeCode() {
        return makeCode;
    }

    public void setMakeCode(String makeCode) {
        this.makeCode = makeCode;
    }

    public String getHandlerCode() {
        return handlerCode;
    }

    public void setHandlerCode(String handlerCode) {
        this.handlerCode = handlerCode;
    }

    public String getHandler1Code() {
        return handler1Code;
    }

    public void setHandler1Code(String handler1Code) {
        this.handler1Code = handler1Code;
    }

    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }

    public String getSellerno() {
        return sellerno;
    }

    public void setSellerno(String sellerno) {
        this.sellerno = sellerno;
    }

    public String getSellername() {
        return sellername;
    }

    public void setSellername(String sellername) {
        this.sellername = sellername;
    }

    public String getAgentcode() {
        return agentcode;
    }

    public void setAgentcode(String agentcode) {
        this.agentcode = agentcode;
    }

    public Integer getSellfeerate() {
        return sellfeerate;
    }

    public void setSellfeerate(Integer sellfeerate) {
        this.sellfeerate = sellfeerate;
    }

    public BigDecimal getCommissionLimit() {
        return commissionLimit;
    }

    public void setCommissionLimit(BigDecimal commissionLimit) {
        this.commissionLimit = commissionLimit;
    }
}

==> sfzn-api-2.0.4-sources.jar: com/picc/gz/sfzn/api/vo/recommend/SalerInfo.java <==
package com.picc.gz.sfzn.api.vo.recommend;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @author Liang Wenxu
 * @since 2018/11/20
 */
public class SalerInfo implements Serializable {
    /**
     * 归属机构码
     */
    private String comCode;
    /**
     * 出单机构码
     */
    private String makeCode;
    /**
     * 经办人码
     */
    private String handlerCode;
    /**
     * 归属业务员码
     */
    private String handler1Code;
    /**
     * 操作员码
     */
    private String operatorCode;

    /**
     * 销售人员码
     */
    private String sellerno;
    /**
     * 销售人员名字
     */
    private String sellername;

    /**
     * 渠道码
     */
    private String agentcode;

    /**
     * 跟单费率，百分比整数，例如0.25传25
     */
    private Integer sellfeerate;

    /**
     * 每月佣金上限（保留2位小数）
     */
    private BigDecimal commissionLimit;


    public String getComCode() {
        return comCode;
    }

    public void setComCode(String comCode) {
        this.comCode = comCode;
    }

    public String getMakeCode() {
        return makeCode;
    }

    public void setMakeCode(String makeCode) {
        this.makeCode = makeCode;
    }

    public String getHandlerCode() {
        return handlerCode;
    }

    public void setHandlerCode(String handlerCode) {
        this.handlerCode = handlerCode;
    }

    public String getHandler1Code() {
        return handler1Code;
    }

    public void setHandler1Code(String handler1Code) {
        this.handler1Code = handler1Code;
    }

    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }

    public String getSellerno() {
        return sellerno;
    }

    public void setSellerno(String sellerno) {
        this.sellerno = sellerno;
    }

    public String getSellername() {
        return sellername;
    }

    public void setSellername(String sellername) {
        this.sellername = sellername;
    }

    public String getAgentcode() {
        return agentcode;
    }

    public void setAgentcode(String agentcode) {
        this.agentcode = agentcode;
    }

    public Integer getSellfeerate() {
        return sellfeerate;
    }

    public void setSellfeerate(Integer sellfeerate) {
        this.sellfeerate = sellfeerate;
    }

    public BigDecimal getCommissionLimit() {
        return commissionLimit;
    }

    public void setCommissionLimit(BigDecimal commissionLimit) {
        this.commissionLimit = commissionLimit;
    }

    @Override
    public String toString() {
        return "SalerInfo{" +
                "comCode='" + comCode + '\'' +
                ", makeCode='" + makeCode + '\'' +
                ", handlerCode='" + handlerCode + '\'' +
                ", handler1Code='" + handler1Code + '\'' +
                ", operatorCode='" + operatorCode + '\'' +
                ", sellerno='" + sellerno + '\'' +
                ", sellername='" + sellername + '\'' +
                ", agentcode='" + agentcode + '\'' +
                ", sellfeerate=" + sellfeerate +
                ", commissionLimit=" + commissionLimit +
                '}';
    }
}
